.. note::

    Ophyd.v2 is included on a provisional basis until the v2.0 release and 
    may change API on minor release numbers before then

API
===

.. automodule:: ophyd.v2

    ``ophyd.v2``
    -----------------------------------

This is the internal API reference for ophyd.v2

.. data:: ophyd.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm


.. autosummary::
    :toctree: ../generated
    :template: custom-module-template.rst
    :recursive:

    ophyd.v2.core
    ophyd.v2.epics
    ophyd.v2.epicsdemo
